==> dolibarr-17.0.2.tgz: dolibarr-17.0.2/htdocs/install/mysql/tables/llx_webhook_target-webhook.sql <==
-- Copyright (C) ---Put here your own copyright and developer email---
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see https://www.gnu.org/licenses/.


CREATE TABLE llx_webhook_target(
	-- BEGIN MODULEBUILDER FIELDS
	rowid integer AUTO_INCREMENT PRIMARY KEY NOT NULL, 
	ref varchar(128) NOT NULL, 
	label varchar(255), 
	description text, 
	note_public text, 
	note_private text, 
	date_creation datetime NOT NULL, 
	tms timestamp DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP, 
	fk_user_creat integer NOT NULL, 
	fk_user_modif integer, 
	import_key varchar(14),
	status integer DEFAULT 0 NOT NULL, 
	url varchar(255) NOT NULL,
	connection_method varchar(255) NULL,	-- to store the way to authenticate to the webhook
	connection_data varchar(255) NULL, 		-- to store the data to use to authenticate to the webhook
	trigger_codes text NULL					-- list of selected trigger that must call the webhook
	-- END MODULEBUILDER FIELDS
) ENGINE=innodb;

==> dolibarr-21.0.1.tgz: dolibarr-21.0.1/htdocs/install/mysql/tables/llx_webhook_target-webhook.sql <==
-- Copyright (C) ---Put here your own copyright and developer email---
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see https://www.gnu.org/licenses/.


CREATE TABLE llx_webhook_target (
	-- BEGIN MODULEBUILDER FIELDS
	rowid integer AUTO_INCREMENT PRIMARY KEY NOT NULL,
	ref varchar(128) NOT NULL,
	label varchar(255),
	description text,
	note_public text,
	note_private text,
	date_creation datetime NOT NULL,
	tms timestamp DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
	fk_user_creat integer NOT NULL,
	fk_user_modif integer,
	import_key varchar(14),
	status integer DEFAULT 0 NOT NULL,
	url varchar(255) NOT NULL,
	connection_method varchar(255) NULL,	-- to store the way to authenticate to the webhook
	connection_data varchar(255) NULL, 		-- to store the data to use to authenticate to the webhook
	trigger_codes text NULL,				-- list of selected trigger that must call the webhook
	trigger_stack text  					-- json object to store trigger to be sent manually
	-- END MODULEBUILDER FIELDS
) ENGINE=innodb;
